# -*- coding: utf-8 -*-
"""
seisclass - Seismic waveform classification package

This package provides functions to classify seismic waveforms using pre-trained models.
"""

__version__ = "0.1.1"

from .check_wave import check_seed

__all__ = ["check_seed"]
